@@ -43,10 +43,18 @@ if (typeof(window['yafowil']) == "undefined") yafowil = {};
                 row +=   '</td>';
                 row +=   '<td>';
                 row +=     '<div class="dict_actions">';
-                row +=       '<a class="dict_row_add" href="#">&nbsp;</a>';
-                row +=       '<a class="dict_row_remove" href="#">&nbsp</a>';
-                row +=       '<a class="dict_row_up" href="#">&nbsp</a>';
-                row +=       '<a class="dict_row_down" href="#">&nbsp</a>';
+                row +=       '<a class="dict_row_add" href="#">';
+                row +=         '<i class="icon-plus-sign">&nbsp;</i>';
+                row +=       '</a>';
+                row +=       '<a class="dict_row_remove" href="#">';
+                row +=         '<i class="icon-minus-sign">&nbsp;</i>';
+                row +=       '</a>';
+                row +=       '<a class="dict_row_up" href="#">';
+                row +=         '<i class="icon-circle-arrow-up">&nbsp;</i>';
+                row +=       '</a>';
+                row +=       '<a class="dict_row_down" href="#">';
+                row +=         '<i class="icon-circle-arrow-down">&nbsp;</i>';
+                row +=       '</a>';
                 row +=     '</div>';
                 row +=   '</td>';
                 row += '</tr>';
